﻿using System;
using ThinkGeo.MapSuite;
using ThinkGeo.MapSuite.iOS;
using ThinkGeo.MapSuite.Layers;
using ThinkGeo.MapSuite.Shapes;
using UIKit;

namespace GettingStarted
{
    public partial class ViewController : UIViewController
    {
        public ViewController(IntPtr handle) : base(handle)
        {
        }

        public override void ViewDidLoad()
        {
            base.ViewDidLoad();
            MapView mapView = new MapView(View.Frame);
            View.Add(mapView);

            mapView.MapUnit = GeographyUnit.Meter;
            mapView.ZoomLevelSet = new CustomZoomLevelSet();

            LayerOverlay layerOverlay = new LayerOverlay();
            OpenStreetMapLayer openStreetMapLayer = new OpenStreetMapLayer();
            openStreetMapLayer.ZoomlevelSet = new CustomZoomLevelSet();
            layerOverlay.Layers.Add(openStreetMapLayer);
            mapView.Overlays.Add(layerOverlay);

            mapView.CurrentExtent = new RectangleShape(-4352400.53526627, 8867834.11959479, 10425951.3896003, -2890780.54967516);
            mapView.Refresh();
        }

        public override void DidReceiveMemoryWarning()
        {
            base.DidReceiveMemoryWarning();
            // Release any cached data, images, etc that aren't in use.
        }
    }

    internal class CustomZoomLevelSet : ZoomLevelSet
    {
        public CustomZoomLevelSet()
        {
            CustomZoomLevels.Clear();
            double worldWidth = 40075016.704;
            double tileWidth = 256;
            for (int i = 0; i < 23; i++)
            {
                double resolution = worldWidth / (tileWidth * Math.Pow(2, i));
                double scale = 39.3701 * 96 * resolution;
                CustomZoomLevels.Add(new ZoomLevel(scale));
            }
        }
    }
}